@@ -6,3 +6,8 @@ class InvalidModelError(Exception):
 class InvalidModelTypeError(Exception):
     def __init__(self, model, orm):
         super().__init__(f"Model {model} is not {orm} model")
+
+
+class UserHasFakeRoleError(Exception):
+    def __init__(self, role_name):
+        super().__init__(f"User has fake role {role_name}")
